from datetime import datetime, timedelta, timezone

from botocore.exceptions import ClientError
from django.core.management.base import BaseCommand

from arkindex.documents.models import CorpusExport, CorpusExportState


class Command(BaseCommand):
    help = 'Clean up old exports'

    def handle(self, *args, **options):
        # Corpus exports that are over 2 weeks old
        old_exports = CorpusExport.objects.filter(created__lt=datetime.now(timezone.utc) - timedelta(weeks=2)).only('id')

        # Only completed exports will have files on S3
        old_exports_with_files = old_exports.filter(state=CorpusExportState.Done)

        self.stdout.write(f'Removing {old_exports_with_files.count()} old corpus exports from S3…')
        for export in old_exports_with_files.iterator():
            self.stdout.write(f'Removing export {export.id} from S3…')
            try:
                export.s3_delete()
            except ClientError as e:
                if e.response['Error']['Code'] == '404':
                    self.stdout.write(f'Export {export.id} not found on S3, skipping')
                else:
                    self.stdout.write(self.style.ERROR(str(e)))

        self.stdout.write(f'Removing {old_exports.count()} old corpus exports…')
        old_exports.delete()

        self.stdout.write(self.style.SUCCESS('Successfully cleaned up old corpus exports.'))
